//////////////////////////////////////////////////////////////////////////
//
//  Copyright (c) 2008-2009, Image Engine Design Inc. All rights reserved.
//
//  Redistribution and use in source and binary forms, with or without
//  modification, are permitted provided that the following conditions are
//  met:
//
//     * Redistributions of source code must retain the above copyright
//       notice, this list of conditions and the following disclaimer.
//
//     * Redistributions in binary form must reproduce the above copyright
//       notice, this list of conditions and the following disclaimer in the
//       documentation and/or other materials provided with the distribution.
//
//     * Neither the name of Image Engine Design nor the names of any
//	     other contributors to this software may be used to endorse or
//       promote products derived from this software without specific prior
//       written permission.
//
//  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
//  IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
//  THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
//  PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
//  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
//  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
//  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
//  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
//  LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
//  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
//  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//
//////////////////////////////////////////////////////////////////////////

#ifndef IE_CORE_COMPOUNDDATACONVERSION_INL
#define IE_CORE_COMPOUNDDATACONVERSION_INL

namespace IECore
{

template<typename C1, typename C2>
CompoundDataConversion<C1, C2>::CompoundDataConversion() : m_c1(), m_c2()
{
}

template<typename C1, typename C2>
CompoundDataConversion<C1, C2>::CompoundDataConversion( const C1 &c1, const C2 &c2 ) : m_c1( c1 ), m_c2( c2 )
{
}

template<typename C1, typename C2>
typename CompoundDataConversion<C1, C2>::ToType CompoundDataConversion<C1, C2>::operator()( typename CompoundDataConversion<C1, C2>::FromType f ) const
{
	return m_c2( m_c1( f ) );
}

template<typename C1, typename C2>
typename CompoundDataConversion<C1, C2>::InverseType CompoundDataConversion<C1, C2>::inverse() const
{
	return InverseType( m_c2.inverse(), m_c1.inverse() );
}

}

#endif // IE_CORE_COMPOUNDDATACONVERSION_INL
